'use strict'

const { program } = require('commander');
const fs = require('fs')
const diffParse = require('parse-diff')
var libxmljs = require("libxmljs");

const app = {
  run() {
    program
      .version('0.0.4')
      .description('Compare cobertura.xml generated by jest with a diff patch file')
      .option('-c, --cobertura <cobertura>', 'The file generated by the (feature) branch you want to check', 'coverage/cobertura.xml')
      .option('-d, --diff <diff>', 'The diff patch file ', 'diff.patch')
      .option('-t, --threshold <threshold>','The minimal threshold code should have', '0.70')
      .option('-v, --variance <variance>','Allow for variance, e.g. allow 0.05 to allow a 5% decrease', '0');
    program.parse(process.argv);
    const options = program.opts();

    console.info(`##Cobertura Diff Coverage ## Version: ${options['version']}`);


    // this example reads the file synchronously
    // you can read it asynchronously also
    let xml_string = fs.readFileSync(options.cobertura, "utf8");
    var files = diffParse(options.diff);
    console.log(files.length);

    let exitCode = 0;
    const minCov = parseFloat(options.new*100);

    if (options.variance!='0') {
      console.log(`Allowed variance is ${options.variance}`);
    }
    
    var xmlDoc = libxmljs.parseXml(xml);
    
    console.info(`Coverage check is completed.`);
    if(exitCode > 0)
    {
      console.info(`Something went wrong, check the logs for more info.`);
    } else {
      console.info(`All the checks have passed succesfully.`);
    }
    process.exit(exitCode);
  },
  getBasePathByProjectPath: function(compareObj, projectPath)
  {
    let basePath = '';
    const compareObjKeys = Object.keys(compareObj);
    for(var i = 0; i < compareObjKeys.length; i++){
      if(compareObjKeys[i]!='total'){
        basePath = compareObjKeys[i].substring(0,compareObjKeys[i].indexOf(projectPath));
        break;
      }
    }
    return basePath;
  }
}

module.exports = app;
